@@ -10,12 +10,9 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-
-import six
-
 import logging
 from collections import defaultdict, deque, namedtuple
-from botocore.compat import accepts_kwargs
+from botocore.compat import accepts_kwargs, six
 
 logger = logging.getLogger(__name__)
 
